@@ -21,25 +21,36 @@ TiddlySpace includes the [[TiddlySpaceLinkPlugin]] which provides WikiText marku
 ***/
 //{{{
 /*jslint onevar: false nomen: false plusplus: false */
-/*global jQuery config createTiddlyText createExternalLink */
+/*global jQuery config createTiddlyText createExternalLink createTiddlyLink */
 
 function createSpaceLink(place, spaceName, title, alt) {
-	var link, a;
+	var link, a, currentSpaceName;
 	try {
 		// seems safe to expect this to have been initialised within TiddlySpace
 		link = config.extensions.tiddlyweb.status.server_host.url;
 	} catch (ex) {
 		link = "http://tiddlyspace.com";
 	}
+	try {
+		if (spaceName === config.extensions.tiddlyspace.currentSpace.name) {
+			a = createTiddlyLink(place, title, false);
+			jQuery(a).text(alt || title);
+			return a;
+		}
+	} catch (ex1) {
+		currentSpaceName = false;
+	}
+
 	// assumes a http URI without user:pass@ prefix
 	link = link.replace("http://", "http://" + spaceName.toLowerCase() + ".");
 
 	if (title) {
 		a = createExternalLink(place, link + "#" + encodeURIComponent(String.encodeTiddlyLink(title)), alt || title);
 	} else {
-		a = createExternalLink(place, link, spaceName);
+		a = createExternalLink(place, link, alt || spaceName);
 	}
-	jQuery(a).addClass('tiddlySpaceLink');
+	jQuery(a).addClass('tiddlySpaceLink').attr('tiddlyspace', spaceName).attr('tiddler', title);
+	return a;
 }
 
 (function ($) {
@@ -53,7 +64,7 @@ function createSpaceLink(place, spaceName, title, alt) {
 		match: config.textPrimitives.unWikiLink + "?" + config.textPrimitives.anyLetter + "*@" + config.textPrimitives.spaceName + ".?",
 		lookaheadRegExp: new RegExp(config.textPrimitives.unWikiLink + "?(" + config.textPrimitives.anyLetter + "*)@(" + config.textPrimitives.spaceName + ")", "mg"),
 		handler: function (w) {
-			if (w.matchText.substr(w.matchText.length-1, 1) === '.') {
+			if (w.matchText.substr(w.matchText.length - 1, 1) === '.') {
 				w.outputText(w.output, w.matchStart, w.nextMatch);
 				return;
 			}
@@ -69,6 +80,22 @@ function createSpaceLink(place, spaceName, title, alt) {
 			}
 		}
 	},
+	{
+		name: "tiddlySpaceLink",
+		match: "\\[\\[[^\\|]*\\|*@" + config.textPrimitives.spaceName + "\\]",
+		lookaheadRegExp: new RegExp("\\[\\[(.*?)(?:\\|@*(.*?))?\\]\\]", "mg"),
+		handler: function (w) {
+			this.lookaheadRegExp.lastIndex = w.matchStart;
+			var lookaheadMatch = this.lookaheadRegExp.exec(w.source);
+			if (lookaheadMatch && lookaheadMatch.index === w.matchStart) {
+				var space = lookaheadMatch[2] || lookaheadMatch[1];
+				space = space.replace(/^@/, "");
+				var alt = lookaheadMatch[1];
+				createSpaceLink(w.output, space, "", alt);
+				w.nextMatch = this.lookaheadRegExp.lastIndex;
+			}
+		}
+	},
 	{
 		name: "tiddlyLinkSpacenameLink",
 		match: "\\[\\[[^\\[]*\\]\\]@",
